@@ -13,11 +13,11 @@ CGI script.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our @countries;
 
@@ -48,7 +48,7 @@ would validate against a US state, and so on.
 
 	CGI::Untaint::CountyStateProvince::US->import();
     } else {
-	die 'Unsupported country ' . $params->{'country'};
+	die 'Unsupported country ', $params->{'country'};
     }
     my $u = CGI::Untaint->new($params);
     my $csp = $u->extract(-as_CountyStateProvince => 'state');
@@ -64,26 +64,24 @@ Validates the data.
 
 sub _untaint_re {
 	# Only allow letters and spaces
-	return qr/^([a-zA-z\s]+)$/;
+	return qr/^([a-zA-Z\s]+)$/;
 }
 
 sub is_valid {
 	my $self = shift;
 
-	unless(scalar(@countries) > 0) {
-		carp "You must specify at least one country";
+	unless(@countries) {
+		carp 'You must specify at least one country';
 		return 0;
 	}
 
-	my $value = $self->value;
+	my $value = $self->value();
 
-	foreach my $country (@countries) {
+	foreach my $country(@countries) {
 		$country->value($value);
-		my $new_value = $country->is_valid();
-		if($new_value) {
-			if($new_value ne $value) {
-				$self->value($new_value);
-			}
+
+		if(my $new_value = $country->is_valid()) {
+			$self->value($new_value) if $new_value ne $value;
 		} else {
 			return 0;
 		}
@@ -92,6 +90,7 @@ sub is_valid {
 	return 1;
 }
 
+
 =head1 AUTHOR
 
 Nigel Horne, C<< <njh at bandsman.co.uk> >>
@@ -102,19 +101,16 @@ Please report any bugs or feature requests to C<bug-cgi-untaint-countystateprovi
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CGI-Untaint-CountyStateProvince>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
 =head1 SEE ALSO
 
 CGI::Untaint
 
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc CGI::Untaint::CountyStateProvince
 
-
 You can also look for information at:
 
 =over 4
@@ -123,23 +119,18 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=CGI-Untaint-CountyStateProvince>
 
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/CGI-Untaint-CountyStateProvince>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/CGI-Untaint-CountyStateProvince>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2019 Nigel Horne.
+Copyright 2012-2025 Nigel Horne.
 
 This program is released under the following licence: GPL2
 
